<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace local_dyslexia;

use core\hook\output\before_standard_head_html_generation;
use html_writer;
use moodle_url;

class hook_callbacks {
    public static function before_standard_html_head(before_standard_head_html_generation $hook): void {
        if (get_user_preferences('local_dyslexia_enable', 0) == 1) {
            $font = get_user_preferences('local_dyslexia_font', form::get_setting_default('font'));
            $hspacing = get_user_preferences('local_dyslexia_hspacing', form::get_setting_default('hspacing'));
            $vspacing = get_user_preferences('local_dyslexia_vspacing', form::get_setting_default('vspacing'));
            $rules = [];
            if ($hspacing) {
                $rules[] = '--local_dyslexia_hspacing:' . $hspacing;
            }
            if ($vspacing) {
                $rules[] = '--local_dyslexia_vspacing:' . $vspacing;
            }
            if (!empty($rules)) {
                $hook->add_html(html_writer::tag('style', ':root{' . implode(';', $rules) . '}'));
            }
            $hook->add_html(html_writer::empty_tag('link',
                    [
                            'rel' => 'stylesheet',
                            'type' => 'text/css',
                            'href' =>  new moodle_url('/local/dyslexia/css/dyslexia_' . $font . '.css'),
                    ]));
        }
    }
}
